@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget.h,v 1.41 2004/04/09 13:38:47 hadess Exp $
+ * $Id: bacon-video-widget.h,v 1.46 2004/07/22 17:59:01 hadess Exp $
  *
  * the xine engine in a widget - header
  */
@@ -33,6 +33,7 @@ G_BEGIN_DECLS
 #define BACON_VIDEO_WIDGET_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), bacon_video_widget_get_type (), BaconVideoWidgetClass))
 #define BACON_IS_VIDEO_WIDGET(obj)           (G_TYPE_CHECK_INSTANCE_TYPE (obj, bacon_video_widget_get_type ()))
 #define BACON_IS_VIDEO_WIDGET_CLASS(klass)   (G_CHECK_INSTANCE_GET_CLASS ((klass), bacon_video_widget_get_type ()))
+#define BVW_ERROR bacon_video_widget_error_quark ()
 
 typedef struct BaconVideoWidgetPrivate BaconVideoWidgetPrivate;
 
@@ -45,7 +46,7 @@ typedef struct {
 	GtkBoxClass parent_class;
 
 	void (*error) (GtkWidget *bvw, const char *message,
-                       gboolean playback_stopped);
+                       gboolean playback_stopped, gboolean fatal);
 	void (*eos) (GtkWidget *bvw);
 	void (*got_metadata) (GtkWidget *bvw);
 	void (*title_change) (GtkWidget *bvw, const char *title);
@@ -56,6 +57,38 @@ typedef struct {
 	void (*speed_warning) (GtkWidget *bvw);
 } BaconVideoWidgetClass;
 
+typedef enum {
+	/* Plugins */
+	BVW_ERROR_AUDIO_PLUGIN,
+	BVW_ERROR_NO_PLUGIN_FOR_FILE,
+	BVW_ERROR_VIDEO_PLUGIN,
+	BVW_ERROR_AUDIO_BUSY,
+	/* File */
+	BVW_ERROR_BROKEN_FILE,
+	BVW_ERROR_FILE_GENERIC,
+	BVW_ERROR_FILE_PERMISSION,
+	BVW_ERROR_FILE_ENCRYPTED,
+	BVW_ERROR_FILE_NOT_FOUND,
+	BVW_ERROR_FILE_PERMISSION,
+	/* Devices */
+	BVW_ERROR_DVD_ENCRYPTED,
+	BVW_ERROR_INVALID_DEVICE,
+	/* Network */
+	BVW_ERROR_UNKNOWN_HOST,
+	BVW_ERROR_NETWORK_UNREACHABLE,
+	BVW_ERROR_CONNECTION_REFUSED,
+	/* Generic */
+	BVW_ERROR_UNVALID_LOCATION,
+	BVW_ERROR_GENERIC,
+	BVW_ERROR_CODEC_NOT_HANDLED,
+	BVW_ERROR_AUDIO_ONLY,
+	BVW_ERROR_CANNOT_CAPTURE,
+	BVW_ERROR_READ_ERROR,
+	BVW_ERROR_PLUGIN_LOAD,
+	BVW_ERROR_STILL_IMAGE
+} BvwError;
+
+GQuark bacon_video_widget_error_quark		 (void) G_GNUC_CONST;
 GType bacon_video_widget_get_type                (void);
 struct poptOption *bacon_video_widget_get_popt_table    (void);
 GtkWidget *bacon_video_widget_new		 (int width, int height,
@@ -135,24 +168,27 @@ G_CONST_RETURN gchar **bacon_video_widget_get_mrls
 						 (BaconVideoWidget *bvw,
 						  MediaType type);
 
+/* Video devices */
+void bacon_video_widget_set_video_device	 (BaconVideoWidget *bvw,
+						  const char *path);
+
 /* Metadata */
 typedef enum {
 	BVW_INFO_TITLE,
 	BVW_INFO_ARTIST,
 	BVW_INFO_YEAR,
 	BVW_INFO_DURATION,
+	BVW_INFO_CDINDEX,
 	/* Video */
 	BVW_INFO_HAS_VIDEO,
 	BVW_INFO_DIMENSION_X,
 	BVW_INFO_DIMENSION_Y,
 	BVW_INFO_VIDEO_CODEC,
-	BVW_INFO_VIDEO_FOURCC,
 	BVW_INFO_FPS,
 	/* Audio */
 	BVW_INFO_HAS_AUDIO,
 	BVW_INFO_BITRATE,
 	BVW_INFO_AUDIO_CODEC,
-	BVW_INFO_AUDIO_FOURCC
 } BaconVideoWidgetMetadataType;
 
 void bacon_video_widget_get_metadata		 (BaconVideoWidget *bvw,
@@ -200,7 +236,8 @@ gboolean bacon_video_widget_get_deinterlacing    (BaconVideoWidget *bvw);
 void bacon_video_widget_set_aspect_ratio         (BaconVideoWidget *bvw,
 						  BaconVideoWidgetAspectRatio
 						  ratio);
-int bacon_video_widget_get_aspect_ratio          (BaconVideoWidget *bvw);
+BaconVideoWidgetAspectRatio bacon_video_widget_get_aspect_ratio
+						 (BaconVideoWidget *bvw);
 
 void bacon_video_widget_set_scale_ratio          (BaconVideoWidget *bvw,
 						  gfloat ratio);
